@@ -41,16 +41,21 @@ GType anjuta_serializer_mode_get_type (void) G_GNUC_CONST;
 /* enumerations from "anjuta-vcs-status.h" */
 GType anjuta_vcs_status_get_type (void) G_GNUC_CONST;
 #define ANJUTA_TYPE_VCS_STATUS (anjuta_vcs_status_get_type())
-/* enumerations from "gbf-project.h" */
-GType gbf_project_error_get_type (void) G_GNUC_CONST;
-#define ANJUTA_TYPE_PROJECT_ERROR (gbf_project_error_get_type())
-GType gbf_project_capabilities_get_type (void) G_GNUC_CONST;
-#define ANJUTA_TYPE_PROJECT_CAPABILITIES (gbf_project_capabilities_get_type())
 /* enumerations from "anjuta-project.h" */
+GType anjuta_project_value_type_get_type (void) G_GNUC_CONST;
+#define ANJUTA_TYPE_PROJECT_VALUE_TYPE (anjuta_project_value_type_get_type())
+GType anjuta_project_property_flags_get_type (void) G_GNUC_CONST;
+#define ANJUTA_TYPE_PROJECT_PROPERTY_FLAGS (anjuta_project_property_flags_get_type())
 GType anjuta_project_node_type_get_type (void) G_GNUC_CONST;
 #define ANJUTA_TYPE_PROJECT_NODE_TYPE (anjuta_project_node_type_get_type())
-GType anjuta_project_target_class_get_type (void) G_GNUC_CONST;
-#define ANJUTA_TYPE_PROJECT_TARGET_CLASS (anjuta_project_target_class_get_type())
+GType anjuta_project_node_state_get_type (void) G_GNUC_CONST;
+#define ANJUTA_TYPE_PROJECT_NODE_STATE (anjuta_project_node_state_get_type())
+/* enumerations from "anjuta-command-queue.h" */
+GType anjuta_command_queue_execute_mode_get_type (void) G_GNUC_CONST;
+#define ANJUTA_TYPE_COMMAND_QUEUE_EXECUTE_MODE (anjuta_command_queue_execute_mode_get_type())
+/* enumerations from "anjuta-command-bar.h" */
+GType anjuta_command_bar_entry_type_get_type (void) G_GNUC_CONST;
+#define ANJUTA_TYPE_COMMAND_BAR_ENTRY_TYPE (anjuta_command_bar_entry_type_get_type())
 G_END_DECLS
 
 #endif /* __ANJUTA_ENUM_TYPES_H__ */
