@@ -36,7 +36,6 @@
 
 #include "search-replace_backend.h"
 #include "search-replace.h"
-#include "search_preferences.h"
 
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <glib/gi18n.h>
@@ -163,8 +162,6 @@ static GladeWidget glade_widgets[] = {
 	{GE_COMBO_ENTRY, "replace.string.combo", NULL, NULL},
 	/* ACTIONS_MAX */
 	{GE_TEXT, "actions.max", NULL, NULL},
-	/* SETTING_PREF_ENTRY */
-	{GE_TEXT, "setting.pref.entry", NULL, NULL},
 	/* SEARCH_REGEX */
 	{GE_BOOLEAN, "search.regex", NULL, NULL},
 	/* GREEDY */
@@ -195,8 +192,6 @@ static GladeWidget glade_widgets[] = {
 	{GE_BOOLEAN, "search.forward", NULL, NULL},
 	/* SEARCH_BACKWARD */
 	{GE_BOOLEAN, "search.backward", NULL, NULL},
-	/* SEARCH_BASIC */
-	{GE_BOOLEAN, "search.basic", NULL, NULL},
 	/* SEARCH_STRING_COMBO */
 	{GE_COMBO, "search.string.combo", NULL, NULL},
 	/* SEARCH_TARGET_COMBO */
@@ -217,8 +212,6 @@ static GladeWidget glade_widgets[] = {
 	{GE_COMBO, "replace.string.combo", NULL, NULL},
 	/* SEARCH_DIRECTION_COMBO */
 	{GE_COMBO, "search.direction.combo", search_direction_strings, NULL},
-	/* SETTING_PREF_TREEVIEW */
-	{GE_NONE, "setting.pref.treeview", NULL, NULL},
 	{GE_NONE, NULL, NULL, NULL}
 };
 
@@ -255,7 +248,7 @@ static void search_set_toggle_direction(SearchDirection dir);
 static void search_disconnect_set_toggle_connect(GladeWidgetId id, 
 	GCallback function, gboolean active);
 static void search_replace_next_previous(SearchDirection dir);
-static void basic_search_toggled(void);
+
 
 static SearchReplaceGUI *sg = NULL;
 
@@ -835,7 +828,7 @@ sr_get_gladewidget(GladeWidgetId id)
 }
 
 static void
-search_set_popdown_strings (GtkComboBoxEntry *combo, GList* strings)
+search_set_popdown_strings (GtkComboBox* combo, GList* strings)
 {
 	GtkListStore *store;
 	gboolean init;
@@ -853,7 +846,7 @@ search_set_popdown_strings (GtkComboBoxEntry *combo, GList* strings)
 	gtk_combo_box_set_model (GTK_COMBO_BOX(combo), GTK_TREE_MODEL (store));
 	g_object_unref (store);
 	
-	if (init) gtk_combo_box_entry_set_text_column (combo, 0);	
+	if (init) gtk_combo_box_set_entry_text_column (combo, 0);
 }
 
 static void
@@ -1213,8 +1206,6 @@ search_replace_populate(void)
 	populate_value(SEARCH_TARGET_COMBO, &(sr->search.range.type));
 	populate_value(SEARCH_DIRECTION_COMBO, &(sr->search.range.direction));
 	populate_value(ACTIONS_NO_LIMIT, &(sr->search.expr.no_limit));
-
-	populate_value(SEARCH_BASIC, &(sr->search.basic_search));
 	
 	if (sr->search.expr.no_limit)
 		sr->search.expr.actions_max = G_MAXINT;	
@@ -1348,9 +1339,6 @@ create_dialog(void)
 	g_signal_connect (widget, "changed", G_CALLBACK (on_search_target_changed), NULL);
 
 
-	search_preferences_initialize_setting_treeview(sg->dialog);
-	search_preferences_init();
-
 	gtk_builder_connect_signals (sg->bxml, NULL);
 	return TRUE;
 }
@@ -1419,7 +1407,7 @@ search_update_combos(void)
 					search_word);
 				sr->search.expr_history = list_max_items(sr->search.expr_history,
 					MAX_ITEMS_SEARCH_COMBO);
-				search_set_popdown_strings(GTK_COMBO_BOX_ENTRY (search_list),
+				search_set_popdown_strings(GTK_COMBO_BOX  (search_list),
 					sr->search.expr_history);
 				
 				//search_toolbar_set_text(search_word);	
@@ -1456,7 +1444,7 @@ replace_update_combos(void)
 					replace_word);
 				sr->replace.expr_history = list_max_items(sr->replace.expr_history,
 					MAX_ITEMS_SEARCH_COMBO);
-				search_set_popdown_strings(GTK_COMBO_BOX_ENTRY (replace_list),
+				search_set_popdown_strings(GTK_COMBO_BOX (replace_list),
 					sr->replace.expr_history);
 			}
 		}
@@ -1509,14 +1497,9 @@ search_update_dialog(void)
 	
 	widget = sr_get_gladewidget(SEARCH_TARGET_COMBO)->widget;
 	search_select_item (GTK_COMBO_BOX(widget), s->range.type);
-	
-	widget = sr_get_gladewidget(SEARCH_BASIC)->widget;
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), s->basic_search);
 
 	widget = sr_get_gladewidget(STOP_BUTTON)->widget; 	
 	gtk_widget_set_sensitive (widget, FALSE);
-
-	basic_search_toggled();
 }
 
 /* -------------- Callbacks --------------------- */
@@ -1537,7 +1520,7 @@ gboolean
 on_search_dialog_key_press_event(GtkWidget *widget, GdkEventKey *event,
                                gpointer user_data)
 {
-	if (event->keyval == GDK_Escape)
+	if (event->keyval == GDK_KEY_Escape)
 	{
 		if (user_data)
 		{
@@ -1555,7 +1538,7 @@ on_search_dialog_key_press_event(GtkWidget *widget, GdkEventKey *event,
 	else
 	{
 		if ( (event->state & GDK_CONTROL_MASK) &&
-				((event->keyval & 0x5F) == GDK_G))
+				((event->keyval & 0x5F) == GDK_KEY_G))
 		{
 			if (event->state & GDK_SHIFT_MASK)
 				search_replace_previous();
@@ -1987,17 +1970,6 @@ on_setting_basic_search_toggled (GtkToggleButton *togglebutton,
 		gtk_widget_hide(frame_basic);
 }
 
-
-static void
-basic_search_toggled(void)
-{
-	GtkToggleButton *togglebutton;
-	
-	togglebutton = GTK_TOGGLE_BUTTON(sr_get_gladewidget(SEARCH_BASIC)->widget);
-	
-	on_setting_basic_search_toggled (togglebutton, NULL);
-}
-
 /***********************************************************************/
 
 #define MAX_LENGTH_SEARCH 64
